====================
The ``lino`` package
====================





Lino is a high-level framework for writing desktop-like customized database
applications based on `Django <https://www.djangoproject.com/>`_ and `Sencha
ExtJS <http://www.sencha.com/products/extjs/>`_. Lino applications are Django
projects where the application developer does not need to write any URLconf,
HTML nor CSS (`more <http://lino-framework.org/about/what.html>`__).

- This repository is considered an integral part of the Lino framework, which is
  documented as a whole in the `Lino Book
  <http://www.lino-framework.org/dev/overview.html>`__.

- Your feedback is welcome.  Our `community page
  <http://www.lino-framework.org/community>`__ explains how to contact us.

- API changes to this repository are logged at
  http://www.lino-framework.org/changes/


